SafaehAccentStyle class
Appearance preference: tone down decorative accent fills.
- Inheritance
-
- Object
- ThemeExtension<
SafaehAccentStyle> - SafaehAccentStyle
- Annotations
Constructors
- SafaehAccentStyle({bool subtleAccents = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtleAccents → bool
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{bool? subtleAccents}) → SafaehAccentStyle -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< SafaehAccentStyle> ? other, double t) → SafaehAccentStyle -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited