SafaehAccentSurfaces class abstract final

Shared decorations for bordered panels and accent heroes.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

emphasizedBorder(ColorScheme colorScheme, {required bool subtle}) Color
emphasizedFill(ColorScheme colorScheme, {required bool subtle}) Color
flatPanel(ColorScheme colorScheme, {double? radius, BuildContext? context}) BoxDecoration
Flat bordered surface used for list/form chrome.
panel(ColorScheme colorScheme, {required bool subtle, Color? accentContainer, Color? accentBorder, double? radius, BuildContext? context}) BoxDecoration
Hero/summary panel; when subtle is true, matches flatPanel.
sectionBar(ColorScheme colorScheme, {required bool subtle}) Color