SafaehAction<T> class

One row for showSafaehActionSheet.

Constructors

SafaehAction({required T value, required String label, String? subtitle, Widget? leading, Widget? trailing, bool selected = false, bool destructive = false, bool enabled = true})
const

Properties

destructive bool
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
leading Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final
subtitle String?
final
trailing Widget?
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited