SafaehAuthLabels class

Copy supplied by the host. Safaeh deliberately has no localization dependency and uses these English values only as a usable fallback.

Constructors

SafaehAuthLabels({String signInTitle = 'Welcome back', String signUpTitle = 'Create your account', String profileTitle = 'Tell us about you', String resetTitle = 'Reset your password', String pendingTitle = 'Check your email', String email = 'Email', String password = 'Password', String displayName = 'Name', String signIn = 'Sign in', String signUp = 'Sign up', String continueLabel = 'Continue', String reset = 'Send reset link', String magicLink = 'Sign in with magic link', String forgotPassword = 'Forgot password?', String switchToSignUp = 'Create an account', String switchToSignIn = 'I already have an account', String back = 'Back', String resend = 'Resend email', String pendingDescription = 'Use the link we sent to finish signing in.', String google = 'Google', String github = 'GitHub', String apple = 'Apple', String otherProvider = 'Continue with provider', String emailDivider = 'or continue with email', String requiredField = 'Required', String invalidEmail = 'Enter a valid email address'})
const

Properties

apple String
final
back String
final
continueLabel String
final
displayName String
final
email String
final
emailDivider String
final
forgotPassword String
final
github String
final
google String
final
hashCode int
The hash code for this object.
no setterinherited
invalidEmail String
final
final
otherProvider String
final
password String
final
pendingDescription String
final
pendingTitle String
final
profileTitle String
final
requiredField String
final
resend String
final
reset String
final
resetTitle String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signIn String
final
signInTitle String
final
signUp String
final
signUpTitle String
final
switchToSignIn String
final
switchToSignUp String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provider(SafaehAuthProvider provider) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited