SafaehAuthLabels constructor

const SafaehAuthLabels({
  1. String signInTitle = 'Welcome back',
  2. String signUpTitle = 'Create your account',
  3. String profileTitle = 'Tell us about you',
  4. String resetTitle = 'Reset your password',
  5. String pendingTitle = 'Check your email',
  6. String email = 'Email',
  7. String password = 'Password',
  8. String displayName = 'Name',
  9. String signIn = 'Sign in',
  10. String signUp = 'Sign up',
  11. String continueLabel = 'Continue',
  12. String reset = 'Send reset link',
  13. String magicLink = 'Sign in with magic link',
  14. String forgotPassword = 'Forgot password?',
  15. String switchToSignUp = 'Create an account',
  16. String switchToSignIn = 'I already have an account',
  17. String back = 'Back',
  18. String resend = 'Resend email',
  19. String pendingDescription = 'Use the link we sent to finish signing in.',
  20. String google = 'Google',
  21. String github = 'GitHub',
  22. String apple = 'Apple',
  23. String otherProvider = 'Continue with provider',
  24. String emailDivider = 'or continue with email',
  25. String requiredField = 'Required',
  26. String invalidEmail = 'Enter a valid email address',
})

Implementation

const SafaehAuthLabels({
  this.signInTitle = 'Welcome back',
  this.signUpTitle = 'Create your account',
  this.profileTitle = 'Tell us about you',
  this.resetTitle = 'Reset your password',
  this.pendingTitle = 'Check your email',
  this.email = 'Email',
  this.password = 'Password',
  this.displayName = 'Name',
  this.signIn = 'Sign in',
  this.signUp = 'Sign up',
  this.continueLabel = 'Continue',
  this.reset = 'Send reset link',
  this.magicLink = 'Sign in with magic link',
  this.forgotPassword = 'Forgot password?',
  this.switchToSignUp = 'Create an account',
  this.switchToSignIn = 'I already have an account',
  this.back = 'Back',
  this.resend = 'Resend email',
  this.pendingDescription = 'Use the link we sent to finish signing in.',
  this.google = 'Google',
  this.github = 'GitHub',
  this.apple = 'Apple',
  this.otherProvider = 'Continue with provider',
  this.emailDivider = 'or continue with email',
  this.requiredField = 'Required',
  this.invalidEmail = 'Enter a valid email address',
});