SafaehAuthSnapshot class

Constructors

SafaehAuthSnapshot({SafaehAuthMode mode = SafaehAuthMode.signIn, bool busy = false, String? errorMessage, String? pendingEmail})
const

Properties

busy bool
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
mode SafaehAuthMode
final
pendingEmail String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited