contentInset property
double
get
contentInset
Extra trailing room for scrollable content, excluding the system inset.
Implementation
double get contentInset => visible ? contentClearance : 0.0;
Extra trailing room for scrollable content, excluding the system inset.
double get contentInset => visible ? contentClearance : 0.0;