SafaehCameraSheet class

Handle for compact↔full camera / QR chrome.

Properties

expanded bool
no setter
hashCode int
The hash code for this object.
no setterinherited
interceptDismiss Future<void> Function()?
Run instead of Navigator.pop when the scrim or handle dismisses.
no getter
openAnimation Animation<double>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismiss() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop<T>([T? result]) → void
setExpanded(bool value) → void
toggleExpanded() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited