leadingWidth property
Horizontal space reserved for leading when computing title insets. Defaults to kToolbarHeight when leading is non-null.
Implementation
final double? leadingWidth;
Horizontal space reserved for leading when computing title insets. Defaults to kToolbarHeight when leading is non-null.
final double? leadingWidth;