minGutterForAlign constant
double
const minGutterForAlign
Minimum free width on the end side before aligned placement is used.
Implementation
static const double minGutterForAlign = 88;
Minimum free width on the end side before aligned placement is used.
static const double minGutterForAlign = 88;