SafaehDebugAction class

Dense list-row action inside a SafaehDebugSection.

Constructors

SafaehDebugAction({required String label, required IconData icon, required VoidCallback onTap, String? subtitle, bool enabled = true})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
label String
final
onTap VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited