SafaehEndAsideLayout class

Places aside in the end gutter of a centered content band.

leftOffset is a physical left inset (use a forced-LTR Row), not a start inset. Pass isRtl so the aside sits on the end. Hisab computes offsets via LayoutBreakpoints.contentBandMetrics.

Inheritance

Constructors

SafaehEndAsideLayout({Key? key, required Widget child, required double leftOffset, required double bandWidth, Widget? aside, double endFree = 0, bool isRtl = false, double asideMinGutter = 176, double asideWidth = 200})
const

Properties

aside Widget?
final
asideMinGutter double
final
asideWidth double
final
bandWidth double
final
child Widget
final
endFree double
final
hashCode int
The hash code for this object.
no setterinherited
isRtl bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftOffset double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited