hideWhenKeyboardVisible property
Hides the bar while the IME is visible. The host shell should also avoid resizing its overlay scaffold during that transition.
Implementation
final bool hideWhenKeyboardVisible;
Hides the bar while the IME is visible. The host shell should also avoid resizing its overlay scaffold during that transition.
final bool hideWhenKeyboardVisible;