SafaehFloatingSurfaceStyle enum

Visual treatment used by floating and overlay surfaces.

Inheritance
Available extensions

Values

solid → const SafaehFloatingSurfaceStyle

An opaque surface without backdrop blur.

translucent → const SafaehFloatingSurfaceStyle

A partially transparent surface without backdrop blur.

glass → const SafaehFloatingSurfaceStyle

A soft, iOS-inspired frosted surface.

vista → const SafaehFloatingSurfaceStyle

A stronger, Vista/Aero-inspired frosted surface.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SafaehFloatingSurfaceStyle>
A constant List of the values in this enum, in order of their declaration.