SafaehL10nEditOverlay class

Long-press wrapper that opens the localization editor.

Inheritance

Constructors

SafaehL10nEditOverlay({Key? key, required SafaehL10nBackend backend, required SafaehL10nOverrideStore store, required GlobalKey<NavigatorState> navigatorKey, required Widget child, SafaehL10nEditorLabels labels = const SafaehL10nEditorLabels(), VoidCallback? onExit, Future<void> onShare(BuildContext context, String json)?})
const

Properties

backend SafaehL10nBackend
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labels SafaehL10nEditorLabels
final
final
onExit VoidCallback?
final
onShare Future<void> Function(BuildContext context, String json)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store SafaehL10nOverrideStore
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SafaehL10nEditOverlay>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited