SafaehMaterialRadii class

Radii and chrome metrics passed to applySafaehMaterialChrome.

Constructors

SafaehMaterialRadii({double card = 12, double input = 12, double chip = 16, double snackBar = 8, bool appBarCenterTitle = true, double appBarElevation = 0, double dividerThickness = 1, double dividerSpacing = 1, double inputDefaultBorderWidth = 1, double inputFocusedBorderWidth = 2, double cardElevation = 0})
const

Properties

appBarCenterTitle bool
final
appBarElevation double
final
card double
final
cardElevation double
final
chip double
final
dividerSpacing double
final
dividerThickness double
final
hashCode int
The hash code for this object.
no setterinherited
input double
final
inputDefaultBorderWidth double
final
inputFocusedBorderWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snackBar double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited