SafaehOnboardingActionBar class

Public action bar. It can be mounted independently in a host flow.

Inheritance

Constructors

SafaehOnboardingActionBar({Key? key, required bool isFirst, required bool isLast, required bool canContinue, required bool busy, required VoidCallback? onBack, required VoidCallback? onNext, Widget? busyIndicator, SafaehOnboardingDesign design = SafaehOnboardingDesign.zen, SafaehOnboardingLabels labels = const SafaehOnboardingLabels(), Widget? leadingAction, Widget? trailingAction, Widget? bottomCenterAction, double? contentMaxWidth, VoidCallback? onSkip, String skipLabel = 'Skip', SafaehOnboardingSkipPlacement skipPlacement = SafaehOnboardingSkipPlacement.bottomEnd})
const

Properties

bottomCenterAction Widget?
Optional host controls rendered in the horizontal center of the split action bar. The onboarding shell uses this for language and theme controls when SafaehOnboardingControlPlacement.bottomCenter is set.
final
busy bool
final
busyIndicator Widget?
final
canContinue bool
final
contentMaxWidth double?
Optional max width for controls while the footer surface stays full-bleed.
final
design SafaehOnboardingDesign
final
hashCode int
The hash code for this object.
no setterinherited
isFirst bool
final
isLast bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labels SafaehOnboardingLabels
final
leadingAction Widget?
final
onBack VoidCallback?
final
onNext VoidCallback?
final
onSkip VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipLabel String
final
skipPlacement SafaehOnboardingSkipPlacement
final
trailingAction Widget?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited