contentMaxWidth property
Optional max width for controls while the footer surface stays full-bleed.
Implementation
final double? contentMaxWidth;
Optional max width for controls while the footer surface stays full-bleed.
final double? contentMaxWidth;