SafaehOnboardingDesignInfo class

Public metadata for a design picker or documentation catalog.

Constructors

SafaehOnboardingDesignInfo({required SafaehOnboardingDesign design, required String id, required String displayName, required String description, required WidgetBuilder previewBuilder})
const

Properties

description String
final
design SafaehOnboardingDesign
final
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
previewBuilder WidgetBuilder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited