SafaehOnboardingLabels class

Localized labels for the onboarding chrome.

Constructors

SafaehOnboardingLabels({String back = 'Back', String next = 'Next', String complete = 'Get started', String skip = 'Skip', String stepProgress(int current, int total)?})
const

Properties

back String
final
complete String
final
hashCode int
The hash code for this object.
no setterinherited
next String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skip String
final
stepProgress String Function(int current, int total)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
progress(int current, int total) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited