SafaehOnboardingSkipPlacement enum

Placement of the optional skip action.

Positions use logical start/end edges so the action mirrors naturally in RTL layouts. For example, topEnd is the top-right corner in LTR and the top-left corner in RTL.

Inheritance
Available extensions

Values

topEnd → const SafaehOnboardingSkipPlacement
topStart → const SafaehOnboardingSkipPlacement
bottomEnd → const SafaehOnboardingSkipPlacement
bottomStart → const SafaehOnboardingSkipPlacement

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isBottom bool

Available on SafaehOnboardingSkipPlacement, provided by the SafaehOnboardingSkipPlacementX extension

no setter
isTop bool

Available on SafaehOnboardingSkipPlacement, provided by the SafaehOnboardingSkipPlacementX extension

no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SafaehOnboardingSkipPlacement>
A constant List of the values in this enum, in order of their declaration.