SafaehPhoneSheetPlacement enum

Where a phone sheet sits. Tablet+ dialogs stay centered.

Inheritance
Available extensions

Values

bottom → const SafaehPhoneSheetPlacement

Compact sheet docked to the bottom (default).

center → const SafaehPhoneSheetPlacement

Taller bottom-docked sheet: the vertical center of the first body block after the handle aligns with the vertical center of the phone.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SafaehPhoneSheetPlacement>
A constant List of the values in this enum, in order of their declaration.