SafaehSidenavDestination class

One shell destination in SafaehSidenav.

Constructors

SafaehSidenavDestination({required String label, required IconData icon, required IconData selectedIcon, Key? tileKey, SafaehLabelBuilder? labelBuilder})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
label String
final
labelBuilder SafaehLabelBuilder?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIcon IconData
final
tileKey Key?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited