SafaehThemeData class

Tokens for safaeh chrome. Override via SafaehTheme at the app root.

Constructors

SafaehThemeData({double tabletBreakpoint = 600, double desktopBreakpoint = 840, double dialogMaxWidth = 560, Duration motion = const Duration(milliseconds: 320), Curve enterCurve = Curves.easeOutCubic, double radius = 16, double listRadius = 12, double compactNavWidth = 72, double expandedNavWidth = 240, Duration navMotion = const Duration(milliseconds: 280), Duration pageIndexMotion = const Duration(milliseconds: 200), Duration sheetRoll = const Duration(milliseconds: 420), Curve sheetRollEnter = const Cubic(0.18, 0.7, 0.2, 1.0), Curve exitCurve = Curves.easeInCubic, double cameraCompactHeightFraction = kSafaehCameraCompactHeightFraction, double contentMaxWidth = 600, double contentMaxWidthDesktop = 720, EdgeInsets sheetBodyInset = const EdgeInsets.fromLTRB(20, 16, 20, 20), EdgeInsets sheetBodyInsetWide = const EdgeInsets.fromLTRB(24, 16, 24, 20), SafaehFloatingAppearance? floatingAppearance})
const

Properties

cameraCompactHeightFraction double
final
compactNavWidth double
final
contentMaxWidth double
Max width of the simple content band on tablet-or-wider viewports.
final
contentMaxWidthDesktop double
Max width of the content band on desktop-or-wider viewports.
final
desktopBreakpoint double
Width at which a host with a pinned shell rail uses the desktop band.
final
dialogMaxWidth double
final
enterCurve Curve
final
exitCurve Curve
final
expandedNavWidth double
final
floatingAppearance SafaehFloatingAppearance?
Default appearance for package-owned floating and overlay surfaces.
final
hashCode int
The hash code for this object.
no setteroverride
listRadius double
Corner radius for list cards (SafaehBorderedListChrome) when ThemeData.cardTheme does not specify a shape.
final
motion Duration
final
final
pageIndexMotion Duration
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sheetBodyInset EdgeInsets
Default body inset under a sheet title bar (phone).
final
sheetBodyInsetWide EdgeInsets
Default body inset under a wide-screen dialog title bar.
final
sheetRoll Duration
final
sheetRollEnter Curve
final
tabletBreakpoint double
final

Methods

contentMaxWidthFor(BuildContext context) double
Tablet band width, or contentMaxWidthDesktop on desktop.
copyWith({double? tabletBreakpoint, double? desktopBreakpoint, double? dialogMaxWidth, Duration? motion, Curve? enterCurve, double? radius, double? listRadius, double? compactNavWidth, double? expandedNavWidth, Duration? navMotion, Duration? pageIndexMotion, Duration? sheetRoll, Curve? sheetRollEnter, Curve? exitCurve, double? cameraCompactHeightFraction, double? contentMaxWidth, double? contentMaxWidthDesktop, EdgeInsets? sheetBodyInset, EdgeInsets? sheetBodyInsetWide, SafaehFloatingAppearance? floatingAppearance}) SafaehThemeData
Copies this theme, replacing any non-null arguments.
isDesktop(BuildContext context) bool
isWide(BuildContext context) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fallback → const SafaehThemeData