SheetHandleBar class
Top grabber for expandable black sheets (receipt camera / invite scanner).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SheetHandleBar
Constructors
- SheetHandleBar({Key? key, required bool expanded, required GestureDragUpdateCallback onVerticalDragUpdate, required GestureDragEndCallback onVerticalDragEnd, required VoidCallback onVerticalDragCancel, Duration? duration, Curve curve = Curves.easeOutCubic, String? semanticLabel, String? expandLabel, String? collapseLabel, String? dismissLabel, VoidCallback? onTap})
-
const
Properties
- collapseLabel → String?
-
Expanded handle. Falls back to dismissLabel, then Material “Dismiss”.
final
- curve → Curve
-
final
- dismissLabel → String?
-
Override for the Material dismiss fallback (tap still dismisses).
final
- duration → Duration?
-
final
- expanded → bool
-
final
- expandLabel → String?
-
Compact handle. Falls back to dismissLabel, then Material “Dismiss”.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTap → VoidCallback?
-
final
- onVerticalDragCancel → VoidCallback
-
final
- onVerticalDragEnd → GestureDragEndCallback
-
final
- onVerticalDragUpdate → GestureDragUpdateCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
Wins over the per-mode labels.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited