SafaehAuthActions class
Host callbacks for the generic auth presentation.
Constructors
-
SafaehAuthActions({Future<
void> onSubmit(SafaehAuthCredentials credentials)?, Future<void> onProfileSubmit(SafaehAuthProfile profile)?, Future<void> onProvider(SafaehAuthProvider provider)?, Future<void> onMagicLink(String email)?, Future<void> onPasswordReset(String email)?, VoidCallback? onToggleMode, VoidCallback? onBack, Future<void> onResend()?}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onBack → VoidCallback?
-
final
-
onMagicLink
→ Future<
void> Function(String email)? -
final
-
onPasswordReset
→ Future<
void> Function(String email)? -
final
-
onProfileSubmit
→ Future<
void> Function(SafaehAuthProfile profile)? -
final
-
onProvider
→ Future<
void> Function(SafaehAuthProvider provider)? -
final
-
onResend
→ Future<
void> Function()? -
final
-
onSubmit
→ Future<
void> Function(SafaehAuthCredentials credentials)? -
final
- onToggleMode → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited