SafaehAuthLabels constructor
const
SafaehAuthLabels({
- String signInTitle = 'Welcome back',
- String signUpTitle = 'Create your account',
- String profileTitle = 'Tell us about you',
- String resetTitle = 'Reset your password',
- String pendingTitle = 'Check your email',
- String email = 'Email',
- String password = 'Password',
- String displayName = 'Name',
- String signIn = 'Sign in',
- String signUp = 'Sign up',
- String continueLabel = 'Continue',
- String reset = 'Send reset link',
- String magicLink = 'Sign in with magic link',
- String forgotPassword = 'Forgot password?',
- String switchToSignUp = 'Create an account',
- String switchToSignIn = 'I already have an account',
- String back = 'Back',
- String resend = 'Resend email',
- String pendingDescription = 'Use the link we sent to finish signing in.',
- String google = 'Google',
- String github = 'GitHub',
- String apple = 'Apple',
- String otherProvider = 'Continue with provider',
- String emailDivider = 'or continue with email',
- String requiredField = 'Required',
- String invalidEmail = 'Enter a valid email address',
Implementation
const SafaehAuthLabels({
this.signInTitle = 'Welcome back',
this.signUpTitle = 'Create your account',
this.profileTitle = 'Tell us about you',
this.resetTitle = 'Reset your password',
this.pendingTitle = 'Check your email',
this.email = 'Email',
this.password = 'Password',
this.displayName = 'Name',
this.signIn = 'Sign in',
this.signUp = 'Sign up',
this.continueLabel = 'Continue',
this.reset = 'Send reset link',
this.magicLink = 'Sign in with magic link',
this.forgotPassword = 'Forgot password?',
this.switchToSignUp = 'Create an account',
this.switchToSignIn = 'I already have an account',
this.back = 'Back',
this.resend = 'Resend email',
this.pendingDescription = 'Use the link we sent to finish signing in.',
this.google = 'Google',
this.github = 'GitHub',
this.apple = 'Apple',
this.otherProvider = 'Continue with provider',
this.emailDivider = 'or continue with email',
this.requiredField = 'Required',
this.invalidEmail = 'Enter a valid email address',
});