SafaehCameraSheetHost class
Paper-roll camera chrome. Use showSafaehCameraSheet for a dialog, or embed this widget on a route (pass onDismiss, omit openAnimation).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SafaehCameraSheetHost
Constructors
-
SafaehCameraSheetHost({Key? key, required SafaehCameraSheetBuilder builder, Animation<
double> ? openAnimation, Future<void> onDismiss()?, double? compactHeightFraction, Color panelColor = Colors.black, Color? scrimColor, Duration? motion, Curve? enterCurve, Curve? exitCurve, double railWidthOf(BuildContext context)?, bool barrierDismissible = true, String? handleExpandLabel, String? handleCollapseLabel, String? handleDismissLabel, SafaehFloatingAppearance? floatingAppearance}) -
const
Properties
- barrierDismissible → bool
-
Scrim tap and, when opened via showSafaehCameraSheet, system back.
final
- builder → SafaehCameraSheetBuilder
-
final
- compactHeightFraction → double?
-
final
- enterCurve → Curve?
-
final
- exitCurve → Curve?
-
final
- floatingAppearance → SafaehFloatingAppearance?
-
Appearance for the camera panel shell and inherited QR top bar.
final
- handleCollapseLabel → String?
-
Expanded handle. Defaults to Material dismiss.
final
- handleDismissLabel → String?
-
Override for the Material dismiss fallback.
final
- handleExpandLabel → String?
-
Compact handle. Defaults to Material dismiss.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- motion → Duration?
-
final
-
onDismiss
→ Future<
void> Function()? -
final
-
openAnimation
→ Animation<
double> ? -
final
- panelColor → Color
-
final
- railWidthOf → double Function(BuildContext context)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrimColor → Color?
-
When null, uses ColorScheme.scrim at 45%. Pass Colors.transparent to
keep tap-to-dismiss while a parent (e.g. a route Scaffold) paints the dim.
final
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SafaehCameraSheetHost> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited