SafaehDebugL10nSection class

Built-in localization section for a SafaehL10nBackend.

Constructors

SafaehDebugL10nSection({required bool editMode, required VoidCallback onToggleEditMode, required VoidCallback onExport, required VoidCallback onClear, required VoidCallback onReload, SafaehL10nEditorLabels labels = const SafaehL10nEditorLabels()})
const

Properties

editMode bool
final
hashCode int
The hash code for this object.
no setterinherited
labels SafaehL10nEditorLabels
final
onClear VoidCallback
final
onExport VoidCallback
final
onReload VoidCallback
final
onToggleEditMode VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSection() SafaehDebugSection
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited