SafaehL10nBackend class abstract
Host i18n engine + bundled maps.
Constructors
Properties
- currentLocale → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locales
→ List<
String> -
no setter
- revision → Listenable
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyLive(
) → Future< void> -
bundled(
String locale) → Map< String, String> -
clearOverrides(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overrides(
String locale) → Map< String, String> -
setOverride(
String locale, String key, String value) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited