SafaehL10nEditorLabels class
Host-supplied copy for the localization editor and debug section.
Constructors
- SafaehL10nEditorLabels({String sectionTitle = 'Localization', String enterEditMode = 'Enter edit mode', String exitEditMode = 'Exit edit mode', String export = 'Export overrides', String clear = 'Clear overrides', String reload = 'Reload translations', String banner = 'Localization edit mode — long-press text to edit', String exitTooltip = 'Exit localization edit mode', String keysTitle = 'Localization keys', String searchTitle = 'Find translation key', String searchHint = 'Search keys or values', String editTitle = 'Edit localization', String exportTitle = 'Export localization overrides', String copy = 'Copy', String save = 'Save'})
-
const
Properties
-
final
- clear → String
-
final
- copy → String
-
final
- editTitle → String
-
final
- enterEditMode → String
-
final
- exitEditMode → String
-
final
- exitTooltip → String
-
final
- export → String
-
final
- exportTitle → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keysTitle → String
-
final
- reload → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- save → String
-
final
- searchHint → String
-
final
- searchTitle → String
-
final
- sectionTitle → String
-
final
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited