SafaehL10nOverrideStore class
Pure-Dart flatten / merge / reverse-lookup store.
Constructors
-
SafaehL10nOverrideStore({required List<
String> locales, SafaehL10nPersistence? persistence})
Properties
- editMode ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locales
→ List<
String> -
final
- overrideCount → int
-
no setter
- persistence → SafaehL10nPersistence?
-
final
-
revision
→ ValueNotifier<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bundledSnapshot(
String locale) → Map< String, dynamic> -
clearAll(
) → Future< void> -
exportJson(
) → String -
findKeysForText(
String text, String locale) → List< String> -
flattenStrings(
Map< String, dynamic> map, [String prefix = '']) → Map<String, String> -
load(
) → Future< void> -
lookupValue(
Map< String, dynamic> map, String key) → String? -
merged(
String locale) → Map< String, dynamic> -
mergeOnto(
Map< String, dynamic> bundled, String locale) → Map<String, dynamic> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overridesFor(
String locale) → Map< String, String> -
remove(
String locale, String key) → void -
save(
) → Future< void> -
set(
String locale, String key, String value) → void -
setBundled(
String locale, Map< String, dynamic> data) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited