leading property
Leading widget. Pass a fixed-width spacer when the title must remain on the physical center line while the action slot changes.
Implementation
final Widget? leading;
Leading widget. Pass a fixed-width spacer when the title must remain on the physical center line while the action slot changes.
final Widget? leading;