SafaehOnboardingHostActions class
Host-controlled actions and optional top/bottom controls.
Constructors
-
SafaehOnboardingHostActions({Widget? languageControl, Widget? themeControl, Widget? leadingAction, Widget? secondaryAction, Future<
SafaehOnboardingResult> onComplete()?, VoidCallback? onSkip, bool busy = false, Widget? busyIndicator, Widget? completionProgress}) -
const
Properties
- busy → bool
-
final
- busyIndicator → Widget?
-
final
- completionProgress → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageControl → Widget?
-
final
- leadingAction → Widget?
-
final
-
onComplete
→ Future<
SafaehOnboardingResult> Function()? -
final
- onSkip → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryAction → Widget?
-
final
- themeControl → Widget?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited