SafaehOnboardingStep class
A host-owned onboarding step.
Safaeh owns the navigation chrome and visual treatment. The host owns the localized content and any stateful domain widgets placed in bodyBuilder.
Constructors
- SafaehOnboardingStep({required String id, required WidgetBuilder titleBuilder, required WidgetBuilder bodyBuilder, WidgetBuilder? subtitleBuilder, bool canContinue = true, bool showTitle = true, bool wrapBodyInScrollView = true})
-
const
Properties
- bodyBuilder → WidgetBuilder
-
final
- canContinue → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showTitle → bool
-
final
- subtitleBuilder → WidgetBuilder?
-
final
- titleBuilder → WidgetBuilder
-
final
- wrapBodyInScrollView → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited