SafaehPageIndexEntry class
One jump target in a long scrolling page.
Constructors
-
SafaehPageIndexEntry({required String id, required String label, required GlobalKey<
State< key, IconData? icon, SafaehLabelBuilder? labelBuilder})StatefulWidget> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
final
- id → String
-
final
-
key
→ GlobalKey<
State< StatefulWidget> > -
final
- label → String
-
final
- labelBuilder → SafaehLabelBuilder?
-
Host bidi / i18n wrapper. Same shape as
SafaehSidenavDestination.labelBuilder.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited