SafaehTextInputSheet class
Text field + action row used by showSafaehTextInput.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SafaehTextInputSheet
Constructors
-
SafaehTextInputSheet({Key? key, required String title, required String doneLabel, String? hint, String initialValue = '', int maxLines = 1, int? maxLength, bool obscureText = false, TextInputType? keyboardType, TextInputAction? textInputAction, List<
TextInputFormatter> ? inputFormatters, bool autocorrect = true, bool enableSuggestions = true, ValueChanged<String> ? onChanged, String? cancelLabel, bool showTitleInBody = true, SafaehTitleBuilder? titleBuilder, double? tabletBreakpoint, bool autofocus = true}) -
const
Properties
- autocorrect → bool
-
final
- autofocus → bool
-
final
- cancelLabel → String?
-
final
- doneLabel → String
-
final
- enableSuggestions → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
- initialValue → String
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- maxLength → int?
-
final
- maxLines → int
-
final
- obscureText → bool
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showTitleInBody → bool
-
final
- tabletBreakpoint → double?
-
final
- textInputAction → TextInputAction?
-
final
- title → String
-
final
- titleBuilder → SafaehTitleBuilder?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SafaehTextInputSheet> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited