SafaehThemeData class
Tokens for safaeh chrome. Override via SafaehTheme at the app root.
Constructors
- SafaehThemeData({double tabletBreakpoint = 600, double dialogMaxWidth = 560, Duration motion = const Duration(milliseconds: 320), Curve enterCurve = Curves.easeOutCubic, double radius = 16, Duration pageIndexMotion = const Duration(milliseconds: 200), Duration sheetRoll = const Duration(milliseconds: 420), Curve sheetRollEnter = const Cubic(0.18, 0.7, 0.2, 1.0), Curve exitCurve = Curves.easeInCubic, double cameraCompactHeightFraction = kSafaehCameraCompactHeightFraction, double contentMaxWidth = 600, SafaehFloatingAppearance? floatingAppearance})
-
const
Properties
- cameraCompactHeightFraction → double
-
final
-
final
- contentMaxWidth → double
-
Max width of the simple content band on wide viewports. Hosts with a shell
rail (Hisab) keep their own band metrics and only use this as a token.
final
- dialogMaxWidth → double
-
final
- enterCurve → Curve
-
final
- exitCurve → Curve
-
final
-
final
- floatingAppearance → SafaehFloatingAppearance?
-
Default appearance for package-owned floating and overlay surfaces.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- motion → Duration
-
final
-
final
- pageIndexMotion → Duration
-
final
- radius → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sheetRoll → Duration
-
final
- sheetRollEnter → Curve
-
final
- tabletBreakpoint → double
-
final
Methods
-
copyWith(
{double? tabletBreakpoint, double? dialogMaxWidth, Duration? motion, Curve? enterCurve, double? radius, Duration? pageIndexMotion, Duration? sheetRoll, Curve? sheetRollEnter, Curve? exitCurve, double? cameraCompactHeightFraction, double? contentMaxWidth, SafaehFloatingAppearance? floatingAppearance}) → SafaehThemeData - Copies this theme, replacing any non-null arguments.
-
isWide(
BuildContext context) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- fallback → const SafaehThemeData