contentMaxWidth property
Max width of the simple content band on wide viewports. Hosts with a shell rail (Hisab) keep their own band metrics and only use this as a token.
Implementation
final double contentMaxWidth;
Max width of the simple content band on wide viewports. Hosts with a shell rail (Hisab) keep their own band metrics and only use this as a token.
final double contentMaxWidth;